@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "casual-avy" "2.0.2"
+(define-package "casual-avy" "20250830.2115"
   "Transient UI for Avy."
   '((emacs  "29.1")
     (avy    "0.5.0")
